# 贡献者公约行为准则

## 我们的承诺

作为社区成员、贡献者和领导者，我们承诺让每个人在参与社区时都能获得免受骚扰的体验，无论其年龄、体型、可见或不可见的残障、民族、性别特征、性别认同与表达、经验水平、教育程度、社会经济地位、国籍、外貌、种族、宗教信仰、性取向或性别认同如何。

我们承诺以促进开放、友好、多元、包容且健康的社区氛围为准则来行动和互动。

## 我们的标准

为我们的社区营造积极环境的行为示例包括：

* 对他人表现出同理心和善意
* 尊重不同的意见、观点和经历
* 给予并优雅地接受建设性反馈
* 承担责任并向受我们错误影响的人道歉，并从经验中学习
* 关注不仅对我们个人最有利的事情，而且对整个社区最有利的事情

不可接受行为的示例包括：

* 使用带有性暗示的语言或图像，以及任何形式的性关注或挑逗行为
* 恶意挑衅、侮辱性或贬损性评论，以及人身或政治攻击
* 公开或私下的骚扰行为
* 未经他人明确许可，公开其私人信息（如住址或电子邮箱）
* 其他在专业场合下被认为不当的行为

## 执行职责

社区领导者负责阐明和执行我们的可接受行为标准，并会对任何他们认为不当、威胁、冒犯或有害的行为采取适当且公正的纠正措施。

社区领导者有权且有责任删除、编辑或拒绝不符合本行为准则的评论、提交、代码、Wiki 编辑、问题和其他贡献，并会在适当时说明审核决策的原因。

## 适用范围

本行为准则适用于所有社区空间，同时也适用于个人在公共场合正式代表社区的情况。代表我们社区的示例包括使用官方电子邮件地址、通过官方社交媒体账号发布内容，或在线上/线下活动中担任指定代表。

## 执行

对于任何辱骂、骚扰或其他不可接受行为的实例，可向负责执行的社区领导者举报，邮箱为 `aw@funstory.ai`。  
所有投诉都将得到及时且公正的审查与调查。  

所有社区领导者均有义务尊重举报人的隐私与安全。

## 执行指南

社区领袖将遵循这些社区影响指南，以确定他们认为违反本行为准则的任何行为的后果：

### 1. 校正

**社区影响**：在社区中使用不当语言或其他被视为不专业或不受欢迎的行为。

**后果**：社区领导者将私下发出书面警告，明确说明违规行为的性质，并解释为何该行为不当。可能会要求公开道歉。

### 2. 警告

**社区影响**：通过单次事件或一系列行为造成的违规。

**后果**：警告并附带对持续行为的处罚措施。在指定期限内不得与相关人员互动，包括未经请求与执行行为准则的人员互动。这包括避免在社区空间及社交媒体等外部渠道的互动。违反这些条款可能导致临时或永久封禁。

### 3. 临时封禁

**社区影响**：严重违反社区标准，包括持续的不当行为。

**后果**：在指定时间内暂时禁止与社区进行任何形式的互动或公开交流。在此期间，不得与相关人员（包括执行行为准则的管理员）进行公开或私下互动。违反这些条款可能导致永久封禁。

### 4. 永久封禁

**社区影响**：表现出违反社区标准的行为模式，包括持续的不当行为、对个人的骚扰，或对某类人群的敌意或贬低。

**后果**：永久禁止在社区内进行任何形式的公开互动。

## 致谢

本行为准则改编自 [贡献者公约][homepage] 2.0 版本，原文可在 https://www.contributor-covenant.org/version/2/0/code_of_conduct.html 查阅。

社区影响指南的灵感来源于 [Mozilla 的行为准则执行阶梯](https://github.com/mozilla/diversity)。

[homepage]: https://www.contributor-covenant.org

关于本行为准则的常见问题解答，请参阅 https://www.contributor-covenant.org/faq 上的常见问题。翻译版本可在 https://www.contributor-covenant.org/translations 获取。

<div align="right"> 
<h6><small>本页面的部分内容由 GPT 翻译，可能包含错误。</small></h6>